@@ -1,9 +1,9 @@
 package Test::Requires;
 use strict;
 use warnings;
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 use base 'Test::Builder::Module';
-use 5.008005;
+use 5.008000;
 
 our @QUEUE;
 
@@ -29,9 +29,8 @@ sub import {
     }
 
     # dequeue one argument
-    if (my $e = shift @QUEUE) {
-        @_ = @$e;
-        goto \&test_requires;
+    for my $e (@QUEUE) {
+        test_requires(@$e);
     }
 }
 
@@ -41,48 +40,38 @@ sub test_requires {
     if (@_ != 3) {
         $caller = caller(0);
     }
+    $ver ||= '';
 
-    my $builder = __PACKAGE__->builder;
+    eval qq{package $caller; use $mod $ver}; ## no critic.
+    if (my $e = $@) {
+        my $skip_all = sub {
+            my $builder = __PACKAGE__->builder;
 
-    package DB;
-    local *DB::_test_requires_foo = sub {
-        $ver ||= '';
-        eval qq{package $caller; use $mod $ver}; ## no critic.
-        if (my $e = $@) {
-            my $skip_all = sub {
-                if (not defined $builder->has_plan) {
-                    $builder->skip_all(@_);
-                } elsif ($builder->has_plan eq 'no_plan') {
-                    $builder->skip(@_);
-                    if ( $builder->parent ) {
-                        die bless {} => 'Test::Builder::Exception';
-                    }
-                    exit 0;
-                } else {
-                    for (1..$builder->has_plan) {
-                        $builder->skip(@_);
-                    }
-                    if ( $builder->parent ) {
-                        die bless {} => 'Test::Builder::Exception';
-                    }
-                    exit 0;
+            if (not defined $builder->has_plan) {
+                $builder->skip_all(@_);
+            } elsif ($builder->has_plan eq 'no_plan') {
+                $builder->skip(@_);
+                if ( $builder->parent ) {
+                    die bless {} => 'Test::Builder::Exception';
                 }
-            };
-            if ( $e =~ /^Can't locate/ ) {
-                $skip_all->("Test requires module '$mod' but it's not found");
-            }
-            else {
-                $skip_all->("$e");
+                exit 0;
+            } else {
+                for (1..$builder->has_plan) {
+                    $builder->skip(@_);
+                }
+                if ( $builder->parent ) {
+                    die bless {} => 'Test::Builder::Exception';
+                }
+                exit 0;
             }
+        };
+        if ( $e =~ /^Can't locate/ ) {
+            $skip_all->("Test requires module '$mod' but it's not found");
         }
-
-        if (@QUEUE > 0) {
-            @_ = @{ shift @QUEUE };
-            goto \&Test::Requires::test_requires;
+        else {
+            $skip_all->("$e");
         }
-    };
-
-    goto \&DB::_test_requires_foo;
+    }
 }
 
 1;
